@@ -1,10 +1,11 @@
+# ruff: noqa: F401
 __title__ = "PySiMMM"
 __author__ = "RyanAugust"
 __license__ = "MIT"
 __copyright__ = "Copyright 2025"
-__version__ = "0.4.3"
+__version__ = "0.5.1"
 
-import os
-
-from .simulate import simmm, multisimmm
+from .simulate import Simulate, Multisim
 from .load_parameters import load_config, define_basic_params
+from .geos import Geos, distribute_to_geos
+from .study import Study, BatchStudy
