@@ -1,9 +1,9 @@
-from pysimmmulator import simmm, command_line
+from pysimmmulator import Simulate, command_line
 import subprocess
 
 
 def test_cli():
-    subprocess.run(["pysimmm", "-i", "example_config.yaml", "-o", "."])
+    subprocess.run(["pysimmm", "-i", "./examples/example_config.yaml", "-o", "."])
     import os
 
     # cleanup
